"""Constants for the Reolink Camera integration."""

DOMAIN = "reolink"

CONF_USE_HTTPS = "use_https"
CONF_PROTOCOL = "protocol"
